@@ -1,4 +1,4 @@
-# Copyright (c) 2017 Ultimaker B.V.
+# Copyright (c) 2019 Ultimaker B.V.
 # Uranium is released under the terms of the LGPLv3 or higher.
 
 import ast
@@ -43,7 +43,7 @@ def _toFloatConversion(value: str) -> float:
     ## Literal eval does not like "02" as a value, but users see this as "2".
     ## We therefore look numbers with leading "0", provided they are not used in variable names
     ## example: "test02 * 20" should not be changed, but "test * 02 * 20" should be changed (into "test * 2 * 20")
-    regex_pattern = '(?<!\.|\w|\d)0+(\d+)'
+    regex_pattern = r"(?<!\.|\w|\d)0+(\d+)"
     value = re.sub(regex_pattern, stripLeading0, value)
 
     try:
@@ -629,10 +629,12 @@ class SettingDefinition:
         "options": {"type": DefinitionPropertyType.Any, "required": False, "read_only": True, "default": {}, "depends_on" : None},
         # Optional comments that apply to the setting. Will be ignored.
         "comments": {"type": DefinitionPropertyType.String, "required": False, "read_only": True, "default": "", "depends_on" : None},
-        # Indicates if this string setting is allowed to have empty value. This can only be used for string settings.
+        # For string type: Indicates if this string setting is allowed to have empty value. This can only be used for string settings.
         "allow_empty": {"type": DefinitionPropertyType.Function, "required": False, "read_only": True, "default": True, "depends_on": None},
-        # Indicates that this string setting should be an UUID. This can only be used for string settings.
+        # For string type: Indicates that this string setting should be an UUID. This can only be used for string settings.
         "is_uuid": {"type": DefinitionPropertyType.Function, "required": False, "read_only": True, "default": False, "depends_on": None},
+        # For string type: If a non-empty string is provided, it will be used as a regex pattern to validate the value string. The value will be invalid if the value string matches the pattern.
+        "regex_blacklist_pattern": {"type": DefinitionPropertyType.String, "required": False, "read_only": True, "default": "", "depends_on": None},
         # For bool type: if the value is the same as the warning value, the setting will be in the warning state.
         "warning_value": {"type": DefinitionPropertyType.Function, "required": False, "read_only": True, "default": None, "depends_on": None},
         # For bool type: if the value is the same as the error value, the setting will be in the error state.
